@@ -1,5 +1,5 @@
 from typing import TypeVar, Generic
-from dataclasses import dataclass
+from dataclasses import dataclass, replace
 from kv import KV, LocatableKV, KVError
 
 T = TypeVar('T')
@@ -21,6 +21,10 @@ class PrefixedKV(KV[T], Generic[T]):
   def has(self, key: str):
     return self.kv.has(self.prefix_ + key)
   
+  def prefixed(self, prefix: str):
+    new_prefix = self.prefix_.rstrip('/') + '/' + prefix.strip('/')
+    return replace(self, prefix_=new_prefix.lstrip('/'))
+  
   async def keys(self):
     async for key in self.kv.keys():
       if key.startswith(self.prefix_):
